from typing import Literal

COLORMAPS = Literal[
	'Circus Ink Purple',
	'Spectrum Parabolic Ramp',
	'Pop cherry',
	'Circus Green',
	'Rainbow RGB',
	'Parabolic RGB',
	'3color-RMB',
	'Pop magenta inverted',
	'Red Hot',
	'Duo Cyan',
	'Yellow',
	'Grays g=0.25 inverted',
	'betterRed',
	'Grays g=1.75',
	'blue_orange_icb',
	'Pop green',
	'mpl-inferno',
	'I Blue',
	'BOP purple',
	'Duo Yellow',
	'Phase Ink Mint-Cherry',
	'betterOrange',
	'Blue',
	'6_shades',
	'Ink Cyan',
	'OIMB3',
	'Quartetto MYGB Blue',
	'Ink Green',
	'Red/Green',
	'Turbo',
	'Circus Ink Black',
	'Duo Green',
	'mpl-viridis',
	'Grays g=0.25',
	'Quartetto RYGB Blue',
	'smart',
	'Thermal',
	'OIMB2',
	'Pop blue inverted',
	'Duo Intense Cherry',
	'Phase Bold Green-Magenta',
	'Quartetto MYGB Magenta',
	'Pop purple inverted',
	'glow',
	'OPF orange',
	'Pop cyan inverted',
	'physics',
	'Phase Ink Yellow-Cyan',
	'Circus Ink Mint',
	'Ink Wash Purple',
	'OIMB1',
	'betterCyan',
	'mpl-magma',
	'Duo Intense Green',
	'edges',
	'Quartetto MYGB Green',
	'Ink Wash Cherry',
	'OPF purple',
	'Ink Wash Cyan',
	'Duo Intense Purple',
	'I Yellow',
	'16_colors',
	'Circus Cyan',
	'Pop lavender inverted',
	'sepia',
	'Duo Intense Cyan',
	'Grays g=1.00 inverted',
	'ICA2',
	'Quartetto RYGB Green',
	'Ink Wash Green',
	'Pop blue',
	'Quartetto RYGB Red',
	'I Forest',
	'ICA3',
	'Circus Yellow',
	'Pop mint',
	'BOP orange',
	'Grays g=1.25 inverted',
	'I Red',
	'3color-CGY',
	'I Green',
	'Fire',
	'Magenta Hot',
	'Grays g=0.50',
	'Orange Hot',
	'Circus Ink Cherry',
	'Pop purple',
	'Ink Yellow',
	'unionjack',
	'Ink Wash Yellow',
	'I Cyan',
	'Cyan Hot',
	'Pop mint inverted',
	'I Magenta',
	'Grays',
	'Phase Green-Magenta',
	'Cyan',
	'Grays g=0.75',
	'Phase Bold Ink Mint-Cherry',
	'Grays g=1.75 inverted',
	'phase',
	'gem',
	'Pop cherry inverted',
	'Pop red',
	'Circus Cherry',
	'OPF fresh',
	'Circus Ink Cyan',
	'betterGreen',
	'Phase Ink Green-Magenta',
	'3color-BMR',
	'Ink Wash Black',
	'Pop red inverted',
	'Duo Purple',
	'betterBlue',
	'Phase Bold Ink Yellow-Cyan',
	'Quartetto RYGB Yellow',
	'Magenta',
	'Duo Mint',
	'Red',
	'Grays g=1.25',
	'I Bordeaux',
	'Grays g=1.50 inverted',
	'Green Hot',
	'glasbey',
	'glasbey_on_dark',
	'mpl-plasma',
	'Ink Cherry',
	'Ink Mint',
	'Circus Ink Yellow',
	'Pop cyan',
	'Pop green inverted',
	'Ink Purple',
	'3color-YGC',
	'Pop yellow',
	'Quartetto MYGB Yellow',
	'Duo Cherry',
	'Green',
	'Grays g=0.50 inverted',
	'Circus Ink Green',
	'ICA',
	'Phase Mint-Cherry',
	'Ink Black',
	'Yellow Hot',
	'Phase Bold Yellow-Cyan',
	'thallium',
	'Pop yellow inverted',
	'Spectrum',
	'royal',
	'glasbey_inverted',
	'betterYellow',
	'Circus Purple',
	'Grays g=2.00',
	'HiLo',
	'cool',
	'Green Fire Blue',
	'Ink Wash Mint',
	'Grays g=0.75 inverted',
	'BOP blue',
	'thal',
	'Ice',
	'Circus Mint',
	'Grays g=1.50',
	'Duo Intense Mint',
	'brgbcmyw',
	'Phase Yellow-Cyan',
	'I Purple',
	'Duo Intense Yellow',
	'Phase Bold Ink Green-Magenta',
	'Pop magenta',
	'3-3-2 RGB',
	'Grays g=2.00 inverted',
	'5_ramps',
	'Phase Bold Mint-Cherry',
]
